/**
 * @file
 * JavaScript for SlidesJS Slider.
 */

(function ($, Drupal, once) {
  'use strict';

  /**
   * SlidesJS slider behavior.
   */
  Drupal.behaviors.slidejsSlider = {
    attach: function (context, settings) {
      once('slidesjs-slider', '.slidesjs-slider-container', context).forEach(function (slider) {
        // Initialize the slider
        new SlidejsSlider(slider);
      });
    }
  };

  /**
   * SlidesJS Slider class.
   *
   * @param {HTMLElement} element
   *   The slider container element.
   */
  function SlidejsSlider(element) {
    this.container = element;
    this.slider = element.querySelector('.slidesjs-slider');
    this.slides = element.querySelectorAll('.slidesjs-slide');
    this.prevButton = element.querySelector('.slidesjs-prev');
    this.nextButton = element.querySelector('.slidesjs-next');
    this.paginationItems = element.querySelectorAll('.slidesjs-pagination-item');
    
    // Get settings
    this.settings = JSON.parse(element.dataset.settings || '{}');
    this.currentSlide = 0;
    this.totalSlides = this.slides.length;
    this.autoPlayTimer = null;
    
    // Initialize
    this.init();
  }

  /**
   * Initialize the slider.
   */
  SlidejsSlider.prototype.init = function () {
    if (this.totalSlides <= 1) {
      return;
    }

    // Set up event listeners
    this.bindEvents();
    
    // Show first slide
    this.showSlide(0);
    
    // Start autoplay if enabled
    if (this.settings.auto_play) {
      this.startAutoPlay();
    }
  };

  /**
   * Bind event listeners.
   */
  SlidejsSlider.prototype.bindEvents = function () {
    const that = this;
    
    // Navigation buttons
    if (this.prevButton) {
      this.prevButton.addEventListener('click', function () {
        that.showPrevSlide();
      });
    }
    
    if (this.nextButton) {
      this.nextButton.addEventListener('click', function () {
        that.showNextSlide();
      });
    }
    
    // Pagination
    this.paginationItems.forEach(function (item, index) {
      item.addEventListener('click', function () {
        that.showSlide(index);
      });
    });
    
    // Pause autoplay on hover
    this.container.addEventListener('mouseenter', function () {
      that.pauseAutoPlay();
    });
    
    this.container.addEventListener('mouseleave', function () {
      if (that.settings.auto_play) {
        that.startAutoPlay();
      }
    });
    
    // Touch events for mobile
    let startX, moveX;
    
    this.container.addEventListener('touchstart', function (e) {
      startX = e.touches[0].clientX;
      that.pauseAutoPlay();
    });
    
    this.container.addEventListener('touchmove', function (e) {
      moveX = e.touches[0].clientX;
    });
    
    this.container.addEventListener('touchend', function () {
      if (startX - moveX > 50) {
        that.showNextSlide();
      } else if (moveX - startX > 50) {
        that.showPrevSlide();
      }
      
      if (that.settings.auto_play) {
        that.startAutoPlay();
      }
    });
  };

  /**
   * Show a specific slide.
   *
   * @param {number} index
   *   The index of the slide to show.
   */
  SlidejsSlider.prototype.showSlide = function (index) {
    // Handle index bounds
    if (index < 0) {
      index = this.totalSlides - 1;
    } else if (index >= this.totalSlides) {
      index = 0;
    }
    
    // Update slider position
    this.slider.style.transform = 'translateX(' + (-100 * index) + '%)';
    
    // Update current slide index
    this.currentSlide = index;
    
    // Update pagination
    this.updatePagination();
  };

  /**
   * Show the next slide.
   */
  SlidejsSlider.prototype.showNextSlide = function () {
    this.showSlide(this.currentSlide + 1);
  };

  /**
   * Show the previous slide.
   */
  SlidejsSlider.prototype.showPrevSlide = function () {
    this.showSlide(this.currentSlide - 1);
  };

  /**
   * Update pagination indicators.
   */
  SlidejsSlider.prototype.updatePagination = function () {
    this.paginationItems.forEach(function (item, index) {
      if (index === this.currentSlide) {
        item.classList.add('active');
      } else {
        item.classList.remove('active');
      }
    }, this);
  };

  /**
   * Start auto play rotation.
   */
  SlidejsSlider.prototype.startAutoPlay = function () {
    const that = this;
    
    // Clear any existing timer
    this.pauseAutoPlay();
    
    // Set new timer
    this.autoPlayTimer = setInterval(function () {
      that.showNextSlide();
    }, this.settings.speed || 3000);
  };

  /**
   * Pause auto play rotation.
   */
  SlidejsSlider.prototype.pauseAutoPlay = function () {
    if (this.autoPlayTimer) {
      clearInterval(this.autoPlayTimer);
      this.autoPlayTimer = null;
    }
  };

})(jQuery, Drupal, once); 